@@ -1,11 +1,7 @@
 #' @include hop2.R
 #' @rdname hop2
 #' @export
-phop <- function(.l,
-                 .starts,
-                 .stops,
-                 .f,
-                 ...) {
+phop <- function(.l, .starts, .stops, .f, ...) {
   phop_impl(
     .l,
     .starts,
@@ -20,12 +16,7 @@ phop <- function(.l,
 
 #' @rdname hop2
 #' @export
-phop_vec <- function(.l,
-                     .starts,
-                     .stops,
-                     .f,
-                     ...,
-                     .ptype = NULL) {
+phop_vec <- function(.l, .starts, .stops, .f, ..., .ptype = NULL) {
   out <- phop_impl(
     .l,
     .starts,
@@ -42,22 +33,23 @@ phop_vec <- function(.l,
 
 # ------------------------------------------------------------------------------
 
-phop_impl <- function(.l,
-                      .starts,
-                      .stops,
-                      .f,
-                      ...,
-                      .ptype,
-                      .constrain,
-                      .atomic) {
-  check_is_list(.l)
+phop_impl <- function(
+  .l,
+  .starts,
+  .stops,
+  .f,
+  ...,
+  .ptype,
+  .constrain,
+  .atomic,
+  .slider_error_call = caller_env()
+) {
+  .l <- slider_check_list(.l, call = .slider_error_call)
+  list_check_all_vectors(.l, call = .slider_error_call)
 
-  lapply(.l, vec_assert)
+  .f <- as_function(.f, call = .slider_error_call)
 
-  .f <- as_function(.f)
-
-  # TODO - more efficiently? reuse elements rather than recycle
-  .l <- vec_recycle_common(!!!.l)
+  .l <- vec_recycle_common(!!!.l, .arg = ".l", .call = .slider_error_call)
 
   type <- vec_size(.l)
 
@@ -72,7 +64,7 @@ phop_impl <- function(.l,
   # into `.f` as argument names
   names(slicers) <- names(.l)
 
-  f_call <- expr(.f(!!! slicers, ...))
+  f_call <- expr(.f(!!!slicers, ...))
 
   hop_common(
     x = .l,
@@ -83,6 +75,7 @@ phop_impl <- function(.l,
     env = environment(),
     type = type,
     constrain = .constrain,
-    atomic = .atomic
+    atomic = .atomic,
+    slider_error_call = .slider_error_call
   )
 }
