@@ -4,7 +4,10 @@ test_that("empty input returns a list, but after the index size check", {
   expect_equal(pslide_index(list(1, integer()), integer(), ~.x), list())
 
   expect_snapshot({
-    (expect_error(pslide_index(list(integer(), integer()), 1, ~.x), class = "slider_error_index_incompatible_size"))
+    (expect_error(
+      pslide_index(list(integer(), integer()), 1, ~.x),
+      class = "slider_error_index_incompatible_size"
+    ))
   })
 })
 
@@ -13,7 +16,11 @@ test_that("completely empty input returns a list", {
 })
 
 test_that("pslide_index() forces arguments in the same way as base R / pmap()", {
-  f_slide <- pslide_index(list(1:2, 1:2, 1:2), 1:2, function(i, j, k) function(x) x + i + j + k)
+  f_slide <- pslide_index(
+    list(1:2, 1:2, 1:2),
+    1:2,
+    function(i, j, k) function(x) x + i + j + k
+  )
   f_base <- mapply(function(i, j, k) function(x) x + i + j + k, 1:2, 1:2, 1:2)
 
   expect_equal(f_slide[[1]](0), f_base[[1]](0))
