@@ -8,7 +8,10 @@ test_that("empty input returns a list, but after the index size check", {
   i <- new_date(0)
 
   expect_snapshot({
-    (expect_error(pslide_period(list(integer(), integer()), i, "day", ~.x), class = "slider_error_index_incompatible_size"))
+    (expect_error(
+      pslide_period(list(integer(), integer()), i, "day", ~.x),
+      class = "slider_error_index_incompatible_size"
+    ))
   })
 })
 
@@ -17,5 +20,14 @@ test_that("completely empty input returns a list", {
 })
 
 test_that("empty input works with `.complete = TRUE` (#111)", {
-  expect_equal(pslide_period(list(integer(), integer()), new_date(), "year", ~.x, .complete = TRUE), list())
+  expect_equal(
+    pslide_period(
+      list(integer(), integer()),
+      new_date(),
+      "year",
+      ~.x,
+      .complete = TRUE
+    ),
+    list()
+  )
 })
